@@ -9,12 +9,9 @@ from .utils import MaxRetry
 
 @MaxRetry(2)
 def get_season_id(media_id: str) -> str:
-    home_url = "https://www.bilibili.com/bangumi/media/md{media_id}".format(media_id=media_id)
-    season_id = ""
-    regex_season_id = re.compile(r'"param":{"season_id":(\d+),"season_type":\d+}')
-    if match_obj := regex_season_id.search(spider.get(home_url, timeout=3).text):
-        season_id = match_obj.group(1)
-    return str(season_id)
+    home_url = "https://api.bilibili.com/pgc/review/user?media_id={media_id}".format(media_id=media_id)
+    res_json = spider.get(home_url).json()
+    return str(res_json["result"]["media"]["season_id"])
 
 
 @MaxRetry(2)
@@ -77,7 +74,7 @@ def get_bangumi_playurl(
     bvid: str = "",
     episode_id: str = "",
     cid: str = "",
-    quality: int = 125,
+    quality: int = 127,
     audio_quality: int = 30280,
     type: str = "dash",
 ):
@@ -116,7 +113,7 @@ def get_bangumi_playurl(
         ]
     elif type == "dash":
         result = []
-        play_api_dash = play_api + "&fnver=0&fnval=16&fourk=1"
+        play_api_dash = play_api + "&fnver=0&fnval=2000&fourk=1"
         play_info = spider.get(
             play_api_dash.format(
                 avid=avid,
@@ -140,7 +137,7 @@ def get_bangumi_playurl(
             if video_quality in accept_video_quality:
                 break
         else:
-            video_quality = 125
+            video_quality = 127
 
         accept_audio_quality = set([audio["id"] for audio in play_info["result"]["dash"]["audio"]])
         for audio_quality in audio_quality_sequence:
